@@ -2,20 +2,20 @@
 
 ;; Copyright (C) 2004, 2005, 2006 Free Software Foundation, Inc.
 
-;; This file is not part of GNU Emacs.
+;; This file is part of Emacs Muse.  It is not part of GNU Emacs.
+
+;; Emacs Muse is free software; you can redistribute it and/or modify
+;; it under the terms of the GNU General Public License as published
+;; by the Free Software Foundation; either version 2, or (at your
+;; option) any later version.
+
+;; Emacs Muse is distributed in the hope that it will be useful, but
+;; WITHOUT ANY WARRANTY; without even the implied warranty of
+;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+;; General Public License for more details.
 
-;; This is free software; you can redistribute it and/or modify it under
-;; the terms of the GNU General Public License as published by the Free
-;; Software Foundation; either version 2, or (at your option) any later
-;; version.
-;;
-;; This is distributed in the hope that it will be useful, but WITHOUT
-;; ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-;; FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
-;; for more details.
-;;
 ;; You should have received a copy of the GNU General Public License
-;; along with GNU Emacs; see the file COPYING.  If not, write to the
+;; along with Emacs Muse; see the file COPYING.  If not, write to the
 ;; Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 ;; Boston, MA 02110-1301, USA.
 
@@ -33,6 +33,7 @@
 
 (require 'muse)
 (require 'muse-publish)
+(require 'cus-edit)
 
 (defgroup muse-project nil
   "Options controlling the behavior of Muse project handling."
@@ -528,7 +529,7 @@ The name of a project may be used for STYLES."
                            (not (string-match exclude-regexp file))))
                      (or (not (file-exists-p file))
                          (not (muse-project-private-p file))))
-            (add-to-list 'used-styles style))))
+            (add-to-list 'used-styles style t))))
       used-styles)))
 
 (defun muse-project-publish-file (file styles &optional force ignore-regexp)
@@ -539,7 +540,7 @@ The name of a project may be used for STYLES."
         ;; ensure the publishing location is available
         (unless (file-exists-p output-dir)
           (message "Creating publishing directory %s" output-dir)
-          (make-directory output-dir))
+          (make-directory output-dir t))
         ;; publish the member file!
         (if (muse-publish-file file style output-dir force)
             (setq published t))))
